﻿Import-Module ActiveDirectory

#Import Group list into variable
$GroupList = Import-Csv "C:\Users\Me\Desktop\Group.csv" -Delimiter ";"
Write-Host "Number of group objects to import: " $GroupList.Count

#Verify that Group exists and if it does not, create it
foreach($Group in $GroupList)
    {
        $GroupName = $Group.Name
        $GroupOU = $Group.OU
        $GroupDescription = $Group.Description
        $GroupDisplayName = $Group.DisplayName
        $GroupFullPath = "AD:\CN=$GroupName,$GroupOU"
        $GroupMail = $Group.Mail
 
        If ((Test-Path -Path $GroupFullPath) -eq $False)
            {
                New-ADGroup -Name $GroupName -DisplayName $GroupDisplayName -SamAccountName $GroupName -Path $GroupOU -GroupCategory Security -GroupScope Global -Description $GroupDescription -OtherAttributes @{"mail"=$GroupMail}
    	    }
        Else
            {
                Write-Host "Group $GroupName already exists in AD!"
            }
    }
#Import Group into Groups
#Import Group list into variable
$UserList = Import-Csv "C:\Users\Me\Desktop\GroupMembers.csv" -Delimiter ";"
Write-Host "Number of AD Groups objects to test: " $UserList.Count

#Verify that Group exists and if it does not, create it
foreach($User in $UserList)
    {
        $GroupName = $User.Group
        $UserName = $User.Member
        $UserId = get-adgroup -Filter * | where {$_.Name -eq $UserName}
        If ($UserId  -eq $Null) 
        {
            Write-Host "$UserName does not exist in AD"
        }
        Else
        {
            Add-ADGroupMember -Identity $GroupName -Members $UserId.SID
        }
    }

#Import Users into Groups
#Import Users list into variable
$UserList = Import-Csv "C:\Users\Me\Desktop\Members.csv" -Delimiter ";"
Write-Host "Number of User objects to test: " $UserList.Count

#Verify that Group exists and if it does not, create it
foreach($User in $UserList)
    {
        $GroupName = $User.GroupName
        $UserName = $User.Member
        $UserIs = get-aduser -Filter * | where {$_.Name -eq $UserName}
        If ($UserIs  -eq $Null) 
        {
            Write-Host "$UserName does not exist in AD"
        }
        Else
        {
            Add-ADGroupMember -Identity $GroupName -Members $UserIs.SID
        }
    }
